@@ -95,8 +95,9 @@ explor_multi_ca <- function(res, settings) {
                ui = navbarPage(gettext("CA", domain = "R-explor"),
                                header = tags$head(
                                                  tags$style(explor_multi_css())),
+                               
                                tabPanel(gettext("Eigenvalues", domain = "R-explor"),
-                                        explor_multi_eigenplotUI("eigenplot", res$eig)),
+                                        explor_multi_eigenUI("eigen", res$eig)),
 
                                tabPanel(gettext("Plot", domain = "R-explor"),
                                         fluidRow(
@@ -140,8 +141,8 @@ explor_multi_ca <- function(res, settings) {
                server = function(input, output) {
 
                    ## Eigenvalues
-                   callModule(explor_multi_eigenplot,
-                              "eigenplot",
+                   callModule(explor_multi_eigen,
+                              "eigen",
                               reactive(res$eig))
 
                    
