@@ -11,9 +11,7 @@ mca <- dudi.acm(d, scannf = FALSE, nf = 5)
 mca$supv <- supcol(mca, dudi.acm(var_sup, scannf = FALSE, nf = 5)$tab)$cosup
 ## Supplementary individuals
 colw <- mca$cw*ncol(d)
-X <- acm.disjonctif(ind_sup)
-X <- data.frame(t(t(X)/colw) - 1)
-mca$supi <- suprow(mca, X)$lisup
+mca$supi <- suprow(mca, ind_sup)$lisup
 iner <- inertia.dudi(mca, row.inertia = TRUE, col.inertia = TRUE)
 
 res <- prepare_results(mca)
@@ -25,9 +23,9 @@ test_that("Eigenvalues are equals", {
 test_that("Variables results are equal", {
   expect_equal(as.vector(round(mca$co[,1],3)),
                res$vars[res$vars$Type == "Active" & res$vars$Axis == "1", "Coord"])
-  expect_equal(as.vector(round(iner$col.rel[,2]/10000,3)),
+  expect_equal(as.vector(round(iner$col.rel[,2]/100,3)),
                res$vars[res$vars$Type == "Active" & res$vars$Axis == "2", "Cos2"])
-  expect_equal(as.vector(round(iner$col.abs[,3]/100,3)),
+  expect_equal(as.vector(round(iner$col.abs[,3],3)),
                res$vars[res$vars$Type == "Active" & res$vars$Axis == "3", "Contrib"])
   expect_equal(as.vector(format(mca$cr[,5], scientific = FALSE, nsmall = 3, digits = 0)),
                data.frame(res$vareta2)[res$vareta2$Type == "Active" & 
@@ -44,9 +42,9 @@ test_that("Qualitative supplementary variables results are equal", {
 test_that("Individuals results are equal", {
   expect_equal(as.vector(round(mca$li[,1],3)),
                data.frame(res$ind)[res$ind$Type == "Active" & res$ind$Axis == "1", "Coord"])
-  expect_equal(as.vector(round(iner$row.abs[,3]/100,3)),
+  expect_equal(as.vector(round(iner$row.abs[,3],3)),
                data.frame(res$ind)[res$ind$Type == "Active" & res$ind$Axis == "3", "Contrib"])
-  expect_equal(as.vector(round(iner$row.rel[,5]/10000,3)),
+  expect_equal(as.vector(round(iner$row.rel[,5]/100,3)),
                data.frame(res$ind)[res$ind$Type == "Active" & res$ind$Axis == "5", "Cos2"])
 })  
   
